parse_chunk_item

Function parse_chunk_item 

pub fn parse_chunk_item(
    buf: &[u8],
    logical: u64,
) -> Option<(ChunkMapping, usize)>
Parse a chunk item (btrfs_chunk + stripes) from a raw byte buffer.

Returns the chunk mapping and the total number of bytes consumed. logical is the logical start address from the key’s offset field.