seed_from_sys_chunk_array

Function seed_from_sys_chunk_array 

pub fn seed_from_sys_chunk_array(array: &[u8], size: u32) -> ChunkTreeCache
Seed a ChunkTreeCache from the superblock’s sys_chunk_array.

The sys_chunk_array contains a subset of chunk items needed to bootstrap access to the full chunk tree (system profile chunks).