sys_chunk_array_contains

Function sys_chunk_array_contains 

pub fn sys_chunk_array_contains(array: &[u8], size: u32, bg_start: u64) -> bool
Walk the superblock’s sys_chunk_array and return true if it already contains a record whose disk_key.offset matches bg_start (i.e. the system chunk starting at that logical address is already part of the bootstrap snippet).