FreeSpaceInfo

Struct FreeSpaceInfo 

pub struct FreeSpaceInfo {
    pub extent_count: u32,
    pub flags: FreeSpaceInfoFlags,
}
Free space info for a block group in the free space tree.

Key: (block_group_offset, FREE_SPACE_INFO, block_group_length).

Fields

extent_count: u32

Number of free extents (or bitmap entries) in this block group.

flags: FreeSpaceInfoFlags

Flags indicating whether this block group uses bitmaps.

Implementations

Source

impl FreeSpaceInfo

pub fn parse(data: &[u8]) -> Option<Self>

Parse a free space info item from a raw byte buffer.