read_chunk_tree

Function read_chunk_tree 

pub fn read_chunk_tree<R: Read + Seek>(
    reader: &mut BlockReader<R>,
    root_logical: u64,
) -> Result<()>
Recursively read the chunk tree to populate the chunk cache.

Starting from the given root block, walks all leaves and inserts any CHUNK_ITEM entries that are not already present in the cache.

Errors

Returns an error if any tree block read fails.