pub struct Item {
pub key: DiskKey,
pub offset: u32,
pub size: u32,
}Expand description
A leaf item descriptor: key + offset/size into the leaf’s data area.
Fields
key: DiskKeyThe three-part key that identifies this item (objectid, type, offset).
offset: u32Byte offset of this item’s data, relative to the end of the item array
(i.e. relative to HEADER_SIZE + nritems * ITEM_SIZE… but actually
it’s an offset from the start of the leaf data area in the C code,
which starts right after the header). See Leaf::item_data().
size: u32Size of this item’s data in bytes.