pub struct CallerOverlay {
pub slot_offset: u32,
pub buf_offset: usize,
pub len: u32,
}Expand description
A range of caller bytes that overlays a data column slot.
Fields
slot_offset: u32Offset within the column slot where the overlay starts
(0 <= slot_offset < stripe_len).
buf_offset: usizeOffset in the caller’s buffer where the overlay bytes start.
len: u32Length of the overlay in bytes
(slot_offset + len <= stripe_len).