pub struct BlockGroupItem {
pub used: u64,
pub chunk_objectid: u64,
pub flags: BlockGroupFlags,
}Expand description
Block group descriptor, tracking space usage for a chunk.
Key: (logical_offset, BLOCK_GROUP_ITEM, length).
Fields
used: u64Bytes used within this block group.
chunk_objectid: u64Objectid of the chunk that backs this block group.
flags: BlockGroupFlagsType and RAID profile flags (DATA, METADATA, SYSTEM, DUP, RAID*, etc.).
Implementations