Block device reader with logical-to-physical address resolution
Provides BlockReader which reads btrfs tree blocks by logical address,
resolving them through the chunk tree cache. Also provides filesystem_open
which bootstraps a complete BlockReader from a raw block device or image.
Structs
- Block
Reader - A block reader that resolves logical addresses through a chunk cache.
- Open
Filesystem - Result of opening a btrfs filesystem from a block device or image.
- Tree
Stats - Statistics collected by walking all blocks of a single B-tree.
Enums
- Traversal
- Tree traversal order.
Functions
- block_
visit - Read a single block and call
visitor(and optionally walk children withfollow). - filesystem_
open - Open a btrfs filesystem by bootstrapping from the superblock.
- filesystem_
open_ mirror - Open a btrfs filesystem using a specific superblock mirror (0, 1, or 2).
- filesystem_
open_ multi - Open a multi-device btrfs filesystem from a map of
devid -> handle. - filesystem_
open_ with_ cache - Open a btrfs filesystem using a pre-built chunk cache.
- read_
chunk_ tree - Recursively read the chunk tree to populate the chunk cache.
- read_
root_ tree - Read the root tree to collect all tree root pointers.
- tree_
stats_ collect - Walk
root_logicalcollectingTreeStats. - tree_
walk - Walk a tree starting at
root_logical, callingvisitorfor each block. - tree_
walk_ mut - Walk a tree (DFS), allowing the visitor to modify each block in place.
- tree_
walk_ tolerant - Walk a tree, continuing past individual block read errors.