pub fn filesystem_open<R: Read + Seek>(reader: R) -> Result<OpenFilesystem<R>>Expand description
Open a btrfs filesystem by bootstrapping from the superblock.
This performs the full bootstrap sequence:
- Read the superblock (mirror 0)
- Seed the chunk cache from the
sys_chunk_array - Read the full chunk tree to complete the cache
- Read the root tree to collect all tree root pointers
Errors
Returns an error if any I/O operation fails during bootstrap.