pub fn read_root_tree<R: Read + Seek>(
reader: &mut BlockReader<R>,
root_logical: u64,
) -> Result<BTreeMap<u64, (u64, u64)>>Expand description
Read the root tree to collect all tree root pointers.
Returns a map of tree_id (objectid) -> (root_bytenr, key_offset).
Errors
Returns an error if any tree block read fails.