Function tree_stats_collect
Source pub fn tree_stats_collect<R: Read + Seek>(
reader: &mut BlockReader<R>,
root_logical: u64,
find_inline: bool,
) -> Result<TreeStats>
Walk root_logical collecting TreeStats.
When find_inline is true the walk also counts inline extent data bytes
(relevant for subvolume / FS trees which contain EXTENT_DATA items).
Errors
Returns an error if any tree block cannot be read.